<footer class="site-footer">
    <hr>
    <section>
        <span>&copy; 2014 <a href="{{ SITEURL }}">{{ SITENAME }}</a></span>&nbsp;&#124;
        <span>Powered by <a href="http://github.com/isubuz/fatafat">Fatafat</a> and <a href="http://github.com/isubuz/simi">Simi</a></span>
    </section>
</footer>
