# -*- coding: utf-8 -*-

"""
This file contains the configuration settings for your fatafat powered blog
and must reside at the root of your blog directory.
"""

SITE_NAME = u'{{ config.SITE_NAME }}'
SITE_URL = u'{{ config.SITE_URL }}'

THEME = u'{{ config.THEME }}'

GITHUB_USERNAME = u'{{ config.GITHUB_USERNAME }}'
DISQUS_SITENAME = u'{{ config.DISQUS_SITENAME }}'