{% extends "base.jinja2" %}
{% block content_title %}{% endblock %}
{% block content %}
<header class="blog-header">
    <a class="blog-title" href="{{ SITEURL }}">{{ SITENAME }}</a>
    <hr>
</header>

{% if articles %}
    <main class="content" role="main">
        {% for article in articles %}
            <article class="post">
                <header class="post-header">
                    <div class="post-title"><a href="{{ SITEURL }}/{{ article.url }}">{{ article.title }}</a>
                    <div class="post-summary">{{ article.summary }}</div>
                </header>
            </article>
        {% endfor %}
    </main>
{% endif %}
{% endblock content %}
