<!DOCTYPE html>
<html lang="{{ DEFAULT_LANG }}">
<head>
    <meta charset="utf-8" />
    <meta http-equiv="X-UA-Compatible" content="IE-edge" />
    <meta name="description" content="" />

    <title>{% block title %}{{ SITENAME }}{%endblock%}</title>

    <!-- Styles 'n' Fonts -->
    <link rel="stylesheet" href="{{ SITEURL }}/assets/css/styles.css" />
    <link href='http://fonts.googleapis.com/css?family=OFL+Sorts+Mill+Goudy+TT:regular,italic' rel='stylesheet' type='text/css' />
</head>
<body>
    <div class="container">
        {% block content %}
        {% endblock %}

        {% include 'footer.jinja2' %}
    </div>
</body>
</html>
