{% extends "base.jinja2" %}
{% block title %}{{ article.title }}{% endblock %}
{% block content %}
<main class="content post-single" role="main">
    <article>
        <!-- Display a single post -->
        <h4 class="post-author"><a href="{{ SITEURL }}">{{ SITENAME }}</a></h4>
        <hr>
        <h1 class="post-title">{{ article.title }}</h1>
        <div class="post-summary">{{ article.summary }}</div>
        <span class="post-meta">{{ article.date.strftime('%B %d, %Y') }}</span>
        <hr>
        <section class="post-content">{{ article.content }}</section>
  </article>
  {% include 'disqus_script.jinja2' %}
</main>
{% endblock %}
