
/* ========================================================================= */
/* Normalize.css v2.1.3 | MIT License | git.io/normalize (minified)
/* ========================================================================= */

article, aside, details,
figcaption, figure,
footer, header, hgroup,
main, nav, section,
summary { display: block; }
audio, canvas, video { display: inline-block; }
audio:not([controls]) { display: none; height: 0; }
[hidden], template { display: none; }
html {
   font-family: sans-serif;
   -ms-text-size-adjust: 100%;
   -webkit-text-size-adjust: 100%;
}
body { margin: 0; }
a { background: transparent; }
a:focus { outline: thin dotted; }
a:active, a:hover { outline: 0; }
h1 { font-size: 2em; margin: 0.67em 0; }
abbr[title] { border-bottom: 1px dotted; }
b, strong { font-weight: bold; }
dfn { font-style: italic; }
hr {
   -moz-box-sizing: content-box;
   box-sizing: content-box;
   height: 0;
}
mark { background: #ff0; color: #000; }
code, kbd, pre,
samp { font-family: monospace, serif; font-size: 1em; }
pre { white-space: pre-wrap; }
q { quotes: "\201C" "\201D" "\2018" "\2019"; }
small { font-size: 80%; }
sub, sup {
   font-size: 75%;
   line-height: 0;
   position: relative;
   vertical-align: baseline;
}
sup { top: -0.5em; }
sub { bottom: -0.25em; }
img { border: 0; }
svg:not(:root) { overflow: hidden; }
figure { margin: 0; }
fieldset {
   border: 1px solid #c0c0c0;
   margin: 0 2px;
   padding: 0.35em 0.625em 0.75em;
}
legend { border: 0; padding: 0; }
button, input, select,
textarea { font-family: inherit; font-size: 100%; margin: 0; }
button, input { line-height: normal; }
button, select { text-transform: none; }
button, html input[type="button"],
input[type="reset"], input[type="submit"] {
   -webkit-appearance: button;
   cursor: pointer;
}
button[disabled], html input[disabled] { cursor: default; }
input[type="checkbox"],
input[type="radio"] { box-sizing: border-box; padding: 0; }
input[type="search"] {
   -webkit-appearance: textfield;
   -moz-box-sizing: content-box;
   -webkit-box-sizing: content-box;
   box-sizing: content-box;
}
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration { -webkit-appearance: none; }
button::-moz-focus-inner,
input::-moz-focus-inner { border: 0; padding: 0; }
textarea { overflow: auto; vertical-align: top; }
table { border-collapse: collapse; border-spacing: 0; }


/* ========================================================================= */
/* Base styles */
/* ========================================================================= */

html, body {
    height: 100%;
}
body {
    color: #333333;
    font-family: "Palatino", serif;
    font-size: 18px;
    line-height: 1.4;
    padding-top: 70px;
}
h1, h2, h3, h4, h5 {
    font-size: 28px;
    font-weight: bold;
    margin-bottom: 20px;
}
a {
    color: #19558d;
    text-decoration: none;
}
a:hover {
    text-decoration: underline;
}
blockquote {
    border-left: 8px solid #ff7f66;
    color: #666666;
    padding-left: 10px;
    position: relative;
    right: 58px;
    width: 100%;
}
pre, code {
    color: #1F1F1F;
    font-family: Consolas, 'Courier New', Menlo, Monaco, monospace !important;
    font-size: 15px;
    line-height: 1.15;
}
pre {
    border: 0;
    padding-left: 30px;
}
hr {
    border: 0;
    border-top: 2px solid #E0E1E1;
    margin: 20px;
    margin-left: 0;
    padding: 0;
    width: 7%;
}

/* ========================================================================= */
/* Styles for index.html */
/* ========================================================================= */

.blog-header {
    margin-bottom: 35px;
}
.blog-header a {
    color: #333333;
    font-weight: bold;
    margin-right: 5px;
}
a.blog-title {
    font-size: 38px;
    font-weight: normal;
}
a.blog-header-links {
    color: #19558d;
}
.post {
    margin-bottom: 25px;
}
.post-title a {
    color: #333333;
    font-family: "OFL Sorts Mill Goudy TT";
    font-size: 23px;
}
.post-summary {
    color: #666666;
    font-family: "OFL Sorts Mill Goudy TT";
    font-style: italic;
}
.post-author {
    font-size: 18px;
    font-weight: bold;
}

/* ========================================================================= */
/* Styles for article.html */
/* ========================================================================= */

.page .post-title, .post-single .post-title {
    font-family: "OFL Sorts Mill Goudy TT";
    font-size: 42px;
    font-weight: bold;
}
.post-single .post-title {
    line-height: 1;
    margin-top: 30px;
}
.post-single .post-summary {
    font-size: 23px;
}
.post-summary {
    margin-bottom: 10px;
}
.post-meta {
    font-size: 16px;
    font-weight: bold
}
.post-content {
    margin-bottom: 60px;
    text-align: justify;
}
.post-content:first-letter {
    font-size: 2.5em;
    line-height: 1;
    margin-right: 2px;
}

/* ========================================================================= */
/* General styles */
/* ========================================================================= */

.container {
    margin: 0 auto;
}
.section-header {
    font-family: "OFL Sorts Mill Goudy TT";
    font-size: 42px;
    font-weight: bold;
}
ul.unstyled {
    list-style-type: none;
    margin: 0;
    padding: 0;
}
ul.unstyled li {
    margin-bottom: 10px;
}


/* ========================================================================= */
/* Styles for page.html */
/* ========================================================================= */

.page hr {
    margin-left: 0;
    width: 7%;
}

/* ========================================================================= */
/* Media styles */
/* ========================================================================= */

/* Smartphones (portrait and landscape) */
@media only screen and (max-width: 599px) {
    .container {
        width: 92%;
    }
}
/* Desktops and laptops */
@media only screen and (min-width: 600px) {
    .container {
        width: 540px;
    }
}

/* ========================================================================= */
/* GIST STYLES */
/* ========================================================================= */
.gist {
    font-size: 14px;
    line-height: 18px;
    margin-bottom: 20px;
    width:100%
}
.gist pre {
    background-color: #FAFAFA;
    font-family: Consolas, Menlo, Monaco, 'Courier New', monospace !important
}
.gist-meta {
    font-family: "Raleway", sans-serif;
    font-size: 13px !important;
}
.gist-meta a {
    color: #26a !important;
    text-decoration:none
}
.gist-meta a:hover {
    color: #0e4071 !important
}
